/*
  $Id: PasswordPolicyAuthenticationResponseHandler.java 2614 2013-02-12 17:47:04Z dfisher $

  Copyright (C) 2003-2013 Virginia Tech.
  All rights reserved.

  SEE LICENSE FOR MORE INFORMATION

  Author:  Middleware Services
  Email:   middleware@vt.edu
  Version: $Revision: 2614 $
  Updated: $Date: 2013-02-12 12:47:04 -0500 (Tue, 12 Feb 2013) $
*/
package org.ldaptive.auth.ext;

import java.util.Calendar;
import org.ldaptive.auth.AuthenticationResponse;
import org.ldaptive.auth.AuthenticationResponseHandler;
import org.ldaptive.control.PasswordPolicyControl;

/**
 * Attempts to parse the authentication response message and set the account
 * state using data associated with a password policy control.
 *
 * @author  Middleware Services
 * @version  $Revision: 2614 $ $Date: 2013-02-12 12:47:04 -0500 (Tue, 12 Feb 2013) $
 */
public class PasswordPolicyAuthenticationResponseHandler
  implements AuthenticationResponseHandler
{


  /** {@inheritDoc} */
  @Override
  public void handle(final AuthenticationResponse response)
  {
    final PasswordPolicyControl ppc = (PasswordPolicyControl)
      response.getControl(PasswordPolicyControl.OID);
    if (ppc != null) {
      Calendar exp = null;
      if (ppc.getTimeBeforeExpiration() > 0) {
        exp = Calendar.getInstance();
        exp.add(Calendar.SECOND, ppc.getTimeBeforeExpiration());
      }
      if (exp != null || ppc.getGraceAuthNsRemaining() > 0) {
        response.setAccountState(
          new PasswordPolicyAccountState(exp, ppc.getGraceAuthNsRemaining()));
      }
      if (response.getAccountState() == null && ppc.getError() != null) {
        response.setAccountState(
          new PasswordPolicyAccountState(ppc.getError()));
      }
    }
  }
}
