/*
  $Id: ControlFactory.java 2589 2013-01-16 17:49:37Z dfisher $

  Copyright (C) 2003-2013 Virginia Tech.
  All rights reserved.

  SEE LICENSE FOR MORE INFORMATION

  Author:  Middleware Services
  Email:   middleware@vt.edu
  Version: $Revision: 2589 $
  Updated: $Date: 2013-01-16 12:49:37 -0500 (Wed, 16 Jan 2013) $
*/
package org.ldaptive.control;

import org.ldaptive.ad.control.DirSyncControl;
import org.ldaptive.ad.control.GetStatsControl;

/**
 * Utility class for creating controls.
 *
 * @author  Middleware Services
 * @version  $Revision: 2589 $ $Date: 2013-01-16 12:49:37 -0500 (Wed, 16 Jan 2013) $
 */
public final class ControlFactory
{


  /** Default constructor. */
  private ControlFactory() {}


  /**
   * Creates a response control from the supplied control data.
   *
   * @param  oid  of the control
   * @param  critical  whether the control is critical
   * @param  encoded  BER encoding of the control
   *
   * @return  response control
   */
  public static ResponseControl createResponseControl(
    final String oid,
    final boolean critical,
    final byte[] encoded)
  {
    ResponseControl ctl;
    if (SortResponseControl.OID.equals(oid)) {
      ctl = new SortResponseControl(critical);
      ctl.decode(encoded);
    } else if (PagedResultsControl.OID.equals(oid)) {
      ctl = new PagedResultsControl(critical);
      ctl.decode(encoded);
    } else if (VirtualListViewResponseControl.OID.equals(oid)) {
      ctl = new VirtualListViewResponseControl(critical);
      ctl.decode(encoded);
    } else if (PasswordPolicyControl.OID.equals(oid)) {
      ctl = new PasswordPolicyControl(critical);
      ctl.decode(encoded);
    } else if (SyncStateControl.OID.equals(oid)) {
      ctl = new SyncStateControl(critical);
      ctl.decode(encoded);
    } else if (SyncDoneControl.OID.equals(oid)) {
      ctl = new SyncDoneControl(critical);
      ctl.decode(encoded);
    } else if (DirSyncControl.OID.equals(oid)) {
      ctl = new DirSyncControl(critical);
      ctl.decode(encoded);
    } else if (GetStatsControl.OID.equals(oid)) {
      ctl = new GetStatsControl(critical);
      ctl.decode(encoded);
    } else if (PasswordExpiredControl.OID.equals(oid)) {
      ctl = new PasswordExpiredControl(critical);
      ctl.decode(encoded);
    } else if (PasswordExpiringControl.OID.equals(oid)) {
      ctl = new PasswordExpiringControl(critical);
      ctl.decode(encoded);
    } else {
      throw new IllegalArgumentException("Unknown OID: " + oid);
    }
    return ctl;
  }
}
