/*
  $Id: HandlerResult.java 2581 2013-01-02 21:16:24Z dfisher $

  Copyright (C) 2003-2013 Virginia Tech.
  All rights reserved.

  SEE LICENSE FOR MORE INFORMATION

  Author:  Middleware Services
  Email:   middleware@vt.edu
  Version: $Revision: 2581 $
  Updated: $Date: 2013-01-02 16:16:24 -0500 (Wed, 02 Jan 2013) $
*/
package org.ldaptive.handler;

/**
 * Handler result data.
 *
 * @param  <T>  type of result
 *
 * @author  Middleware Services
 * @version  $Revision: 2581 $ $Date: 2013-01-02 16:16:24 -0500 (Wed, 02 Jan 2013) $
 */
public class HandlerResult<T>
{

  /** Result produced by a handler. */
  private final T result;

  /** Whether the operation should be aborted. */
  private final boolean abort;


  /**
   * Creates a new handler result.
   *
   * @param  t  produced by a handler
   */
  public HandlerResult(final T t)
  {
    result = t;
    abort = false;
  }


  /**
   * Creates a new handler result.
   *
   * @param  t  produced by a handler
   * @param  b  whether the operation should be aborted
   */
  public HandlerResult(final T t, final boolean b)
  {
    result = t;
    abort = b;
  }


  /**
   * Returns the result produced by a handler.
   *
   * @return  result
   */
  public T getResult()
  {
    return result;
  }


  /**
   * Returns whether the operation should be aborted.
   *
   * @return  whether the operation should be aborted
   */
  public boolean getAbort()
  {
    return abort;
  }
}
