/*
  $Id: IntermediateResponseFactory.java 2591 2013-01-25 16:15:19Z dfisher $

  Copyright (C) 2003-2013 Virginia Tech.
  All rights reserved.

  SEE LICENSE FOR MORE INFORMATION

  Author:  Middleware Services
  Email:   middleware@vt.edu
  Version: $Revision: 2591 $
  Updated: $Date: 2013-01-25 11:15:19 -0500 (Fri, 25 Jan 2013) $
*/
package org.ldaptive.intermediate;

import org.ldaptive.control.ResponseControl;

/**
 * Utility class for creating intermediate responses.
 *
 * @author  Middleware Services
 * @version  $Revision: 2591 $ $Date: 2013-01-25 11:15:19 -0500 (Fri, 25 Jan 2013) $
 */
public final class IntermediateResponseFactory
{


  /** Default constructor. */
  private IntermediateResponseFactory() {}


  /**
   * Creates an intermediate response from the supplied response data.
   *
   * @param  oid  of the response
   * @param  encoded  BER encoding of the response
   * @param  responseControls  associated with this response
   * @param  msgId  message id associated with this response
   *
   * @return  intermediate response
   */
  public static IntermediateResponse createIntermediateResponse(
    final String oid,
    final byte[] encoded,
    final ResponseControl[] responseControls,
    final int msgId)
  {
    IntermediateResponse res;
    if (SyncInfoMessage.OID.equals(oid)) {
      res = new SyncInfoMessage(responseControls, msgId);
      res.decode(encoded);
    } else {
      throw new IllegalArgumentException("Unknown OID: " + oid);
    }
    return res;
  }
}
