/*
  $Id: SSLContextInitializer.java 2592 2013-01-28 23:01:42Z dfisher $

  Copyright (C) 2003-2013 Virginia Tech.
  All rights reserved.

  SEE LICENSE FOR MORE INFORMATION

  Author:  Middleware Services
  Email:   middleware@vt.edu
  Version: $Revision: 2592 $
  Updated: $Date: 2013-01-28 18:01:42 -0500 (Mon, 28 Jan 2013) $
*/
package org.ldaptive.ssl;

import java.security.GeneralSecurityException;
import javax.net.ssl.KeyManager;
import javax.net.ssl.SSLContext;
import javax.net.ssl.TrustManager;

/**
 * Provides an interface for the initialization of new SSL contexts.
 *
 * @author  Middleware Services
 * @version  $Revision: 2592 $ $Date: 2013-01-28 18:01:42 -0500 (Mon, 28 Jan 2013) $
 */
public interface SSLContextInitializer
{


  /**
   * Creates an initialized SSLContext for the supplied protocol.
   *
   * @param  protocol  type to use for SSL
   *
   * @return  SSL context
   *
   * @throws  GeneralSecurityException  if the SSLContext cannot be created
   */
  SSLContext initSSLContext(String protocol)
    throws GeneralSecurityException;


  /**
   * Returns the trust managers used when creating SSL contexts.
   *
   * @return  trust managers
   *
   * @throws  GeneralSecurityException  if an errors occurs while loading the
   * TrustManagers
   */
  TrustManager[] getTrustManagers()
    throws GeneralSecurityException;


  /**
   * Sets the trust managers. May be in isolation or in conjunction with other
   * trust material.
   *
   * @param  managers  trust managers
   */
  void setTrustManagers(TrustManager... managers);


  /**
   * Returns the key managers used when creating SSL contexts.
   *
   * @return  key managers
   *
   * @throws  GeneralSecurityException  if an errors occurs while loading the
   * KeyManagers
   */
  KeyManager[] getKeyManagers()
    throws GeneralSecurityException;
}
